@@ -18,10 +18,17 @@ import collections
 import datetime
 import operator
 
+import numpy
 from oslo_config import cfg
 from oslo_config import types
 import six
 
+from gnocchi import carbonara
+from gnocchi import utils
+
+
+ATTRGETTER_GRANULARITY = operator.attrgetter("granularity")
+
 
 class ArchivePolicy(object):
 
@@ -35,6 +42,10 @@ class ArchivePolicy(object):
          'std', 'median', 'first', 'count')).union(
              set((str(i) + 'pct' for i in six.moves.range(1, 100))))
 
+    VALID_AGGREGATION_METHODS = VALID_AGGREGATION_METHODS.union(
+        set(map(lambda s: "rate:" + s,
+                VALID_AGGREGATION_METHODS)))
+
     # Set that contains all the above values + their minus equivalent (-mean)
     # and the "*" entry.
     VALID_AGGREGATION_METHODS_VALUES = VALID_AGGREGATION_METHODS.union(
@@ -71,13 +82,37 @@ class ArchivePolicy(object):
             raise ValueError(
                 "More than one archive policy "
                 "uses granularity `%s'"
-                % duplicate_granularities[0]
+                % utils.timespan_total_seconds(duplicate_granularities[0])
             )
 
         if aggregation_methods is None:
             self.aggregation_methods = self.DEFAULT_AGGREGATION_METHODS
         else:
-            self.aggregation_methods = aggregation_methods
+            self.aggregation_methods = set(aggregation_methods)
+
+    def get_aggregation(self, method, granularity):
+        # Find the timespan
+        for d in self.definition:
+            if d.granularity == granularity:
+                return carbonara.Aggregation(
+                    method, d.granularity, d.timespan)
+
+    def get_aggregations_for_method(self, method):
+        """Return a list of aggregation for a method.
+
+        List is sorted by granularity, desc.
+
+        :param method: Aggregation method.
+        """
+        return [carbonara.Aggregation(method, d.granularity, d.timespan)
+                for d in sorted(self.definition,
+                                key=ATTRGETTER_GRANULARITY, reverse=True)]
+
+    @property
+    def aggregations(self):
+        return [carbonara.Aggregation(method, d.granularity, d.timespan)
+                for d in sorted(self.definition, key=ATTRGETTER_GRANULARITY)
+                for method in self.aggregation_methods]
 
     @property
     def aggregation_methods(self):
@@ -141,8 +176,7 @@ OPTS = [
         'default_aggregation_methods',
         item_type=types.String(
             choices=ArchivePolicy.VALID_AGGREGATION_METHODS),
-        default=['mean', 'min', 'max', 'sum',
-                 'std', 'median', 'count', '95pct'],
+        default=['mean', 'min', 'max', 'sum', 'std', 'count'],
         help='Default aggregation methods to use in created archive policies'),
 ]
 
@@ -156,26 +190,33 @@ class ArchivePolicyItem(dict):
                 raise ValueError(
                     u"timespan ≠ granularity × points")
 
-        if granularity is not None and granularity <= 0:
-            raise ValueError("Granularity should be > 0")
+        if granularity is not None:
+            if not isinstance(granularity, numpy.timedelta64):
+                granularity = numpy.timedelta64(int(granularity * 10e8), 'ns')
+            if granularity <= numpy.timedelta64(0, 'ns'):
+                raise ValueError("Granularity should be > 0")
 
         if points is not None and points <= 0:
             raise ValueError("Number of points should be > 0")
 
+        if (timespan is not None
+           and not isinstance(timespan, numpy.timedelta64)):
+            timespan = numpy.timedelta64(int(timespan * 10e8), 'ns')
+
         if granularity is None:
             if points is None or timespan is None:
                 raise ValueError(
                     "At least two of granularity/points/timespan "
                     "must be provided")
-            granularity = round(timespan / float(points))
-        else:
-            granularity = float(granularity)
+            granularity = timespan / float(points)
 
         if points is None:
             if timespan is None:
                 self['timespan'] = None
             else:
                 points = int(timespan / granularity)
+                if points <= 0:
+                    raise ValueError("Calculated number of points is < 0")
                 self['timespan'] = granularity * points
         else:
             points = int(points)
@@ -200,44 +241,66 @@ class ArchivePolicyItem(dict):
         """Return a dict representation with human readable values."""
         return {
             'timespan': six.text_type(
-                datetime.timedelta(seconds=self.timespan))
+                datetime.timedelta(
+                    seconds=utils.timespan_total_seconds(
+                        self.timespan)))
             if self.timespan is not None
             else None,
             'granularity': six.text_type(
-                datetime.timedelta(seconds=self.granularity)),
+                datetime.timedelta(
+                    seconds=utils.timespan_total_seconds(
+                        self.granularity))),
+            'points': self.points,
+        }
+
+    def serialize(self):
+        return {
+            'timespan': None
+            if self.timespan is None
+            else float(utils.timespan_total_seconds(self.timespan)),
+            'granularity': float(
+                utils.timespan_total_seconds(self.granularity)),
             'points': self.points,
         }
 
 
 DEFAULT_ARCHIVE_POLICIES = {
+    'bool': ArchivePolicy(
+        "bool", 3600, [
+            # 1 second resolution for 365 days
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 's'),
+                              timespan=numpy.timedelta64(365, 'D')),
+        ],
+        aggregation_methods=("last",),
+    ),
     'low': ArchivePolicy(
         "low", 0, [
-            # 5 minutes resolution for an hour
-            ArchivePolicyItem(granularity=300, points=12),
-            # 1 hour resolution for a day
-            ArchivePolicyItem(granularity=3600, points=24),
-            # 1 day resolution for a month
-            ArchivePolicyItem(granularity=3600 * 24, points=30),
+            # 5 minutes resolution for 30 days
+            ArchivePolicyItem(granularity=numpy.timedelta64(5, 'm'),
+                              timespan=numpy.timedelta64(30, 'D')),
         ],
     ),
     'medium': ArchivePolicy(
         "medium", 0, [
-            # 1 minute resolution for an day
-            ArchivePolicyItem(granularity=60, points=60 * 24),
-            # 1 hour resolution for a week
-            ArchivePolicyItem(granularity=3600, points=7 * 24),
-            # 1 day resolution for a year
-            ArchivePolicyItem(granularity=3600 * 24, points=365),
+            # 1 minute resolution for 7 days
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 'm'),
+                              timespan=numpy.timedelta64(7, 'D')),
+            # 1 hour resolution for 365 days
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 'h'),
+                              timespan=numpy.timedelta64(365, 'D')),
         ],
     ),
     'high': ArchivePolicy(
         "high", 0, [
             # 1 second resolution for an hour
-            ArchivePolicyItem(granularity=1, points=3600),
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 's'),
+                              timespan=numpy.timedelta64(1, 'h')),
             # 1 minute resolution for a week
-            ArchivePolicyItem(granularity=60, points=60 * 24 * 7),
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 'm'),
+                              timespan=numpy.timedelta64(7, 'D')),
             # 1 hour resolution for a year
-            ArchivePolicyItem(granularity=3600, points=365 * 24),
+            ArchivePolicyItem(granularity=numpy.timedelta64(1, 'h'),
+                              timespan=numpy.timedelta64(365, 'D')),
         ],
     ),
 }
